Module: LcpRuby::BackgroundJobs::ScheduleAdapter
- Defined in:
- lib/lcp_ruby/background_jobs/schedule_adapter.rb
Instance Method Summary collapse
-
#sync_schedules!(definitions) ⇒ Object
Idempotent full sync: receives ALL active scheduled job definitions.
Instance Method Details
#sync_schedules!(definitions) ⇒ Object
Idempotent full sync: receives ALL active scheduled job definitions. Must add new schedules, update changed ones, and remove schedules for definitions no longer in the list.
9 10 11 |
# File 'lib/lcp_ruby/background_jobs/schedule_adapter.rb', line 9 def sync_schedules!(definitions) raise NotImplementedError, "#{self.class}#sync_schedules! must be implemented" end |