Exception: LcpRuby::Pages::PageNotFoundError

Inherits:
MetadataError show all
Defined in:
lib/lcp_ruby.rb

Overview

Raised when a slug-based lookup cannot find a routable page. A subclass of MetadataError so existing ‘rescue LcpRuby::MetadataError` blocks continue to work, but specific enough that controllers (e.g. PresenterSetup) can rescue it and translate to a proper 404 instead of a 500.

Instance Attribute Summary

Attributes inherited from Error

#i18n_interpolations, #i18n_key

Method Summary

Methods inherited from Error

#initialize, #localized_message

Constructor Details

This class inherits a constructor from LcpRuby::Error