Class: LcpRuby::Workflow::ChangeHandler
- Inherits:
-
Object
- Object
- LcpRuby::Workflow::ChangeHandler
- Defined in:
- lib/lcp_ruby/workflow/change_handler.rb
Class Method Summary collapse
-
.install!(model_class) ⇒ Object
Installs after_commit callbacks on the workflow model to invalidate caches.
Class Method Details
.install!(model_class) ⇒ Object
Installs after_commit callbacks on the workflow model to invalidate caches.
6 7 8 9 10 11 |
# File 'lib/lcp_ruby/workflow/change_handler.rb', line 6 def self.install!(model_class) model_class.after_commit do |_record| Registry.reload! Authorization::PolicyFactory.clear! end end |